contexttools.iterate_contexts_forward_in_expr
=============================================

.. autofunction:: abjad.tools.contexttools.iterate_contexts_forward_in_expr.iterate_contexts_forward_in_expr
